@@ -15,6 +15,7 @@
 #define QT_FEATURE_identityproxymodel 1
 #define QT_FEATURE_library 1
 #define QT_FEATURE_mimetype 1
+#define QT_FEATURE_processenvironment 1
 #define QT_FEATURE_process 1
 #define QT_FEATURE_statemachine 1
 #define QT_FEATURE_qeventtransition 1
@@ -22,6 +23,7 @@
 #define QT_FEATURE_settings 1
 #define QT_FEATURE_sharedmemory 1
 #define QT_FEATURE_sortfilterproxymodel 1
+#define QT_FEATURE_std_atomic64 1
 #define QT_FEATURE_stringlistmodel 1
 #define QT_FEATURE_systemsemaphore 1
 #define QT_FEATURE_temporaryfile 1
